diff --git a/Makefile.am b/Makefile.am
index 2fb3ed0..cb43701 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,4 +1,4 @@
-SUBDIRS = src content
+SUBDIRS = src content po
schemadir = $(GCONF_SCHEMA_FILE_DIR)
schema_DATA = mobile-basic-flash.schemas
diff --git a/configure.ac b/configure.ac
index 93c4041..cad31dc 100644
--- a/configure.ac
+++ b/configure.ac
@@ -27,6 +27,18 @@ CFLAGS="$CFLAGS -Wall -ansi -Wmissing-prototypes -Wmissing-declarations -std=c99
AC_SUBST(CFLAGS)
#+++++++++++++++++++++
+# Gettext support
+#+++++++++++++++++++++
+
+GETTEXT_PACKAGE=mobile-basic-flash
+AC_SUBST(GETTEXT_PACKAGE)
+
+AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE, "$GETTEXT_PACKAGE", "definition of GETTEXT_PACKAGE")
+
+AM_GLIB_GNU_GETTEXT
+AM_GLIB_DEFINE_LOCALEDIR([LOCALEDIR])
+
+#+++++++++++++++++++++
# Dependencies checks
#+++++++++++++++++++++
@@ -76,6 +88,7 @@ Makefile
src/Makefile
src/mobile-basic-home.desktop
content/Makefile
+po/Makefile.in
])
AC_OUTPUT
diff --git a/content/flash_home.html b/content/flash_home.html
index 961ac72..0100187 100644
--- a/content/flash_home.html
+++ b/content/flash_home.html
@@ -10,8 +10,8 @@
-
-
+
+
diff --git a/content/flash_home.js b/content/flash_home.js
index 5e4bb71..457faa4 100644
--- a/content/flash_home.js
+++ b/content/flash_home.js
@@ -33,6 +33,7 @@ function getFlashFile() {
} else if (screen.width==800 && screen.height==480) {
flashFile = "flash_home_800x480.swf";
}
+ }
var flashDiv = document.getElementById ('flashDiv');
if (flashDiv) {
// don't substract the marquee size if we are hiding it
diff --git a/content/grid_home.html b/content/grid_home.html
index fa1ceb3..f441bd7 100644
--- a/content/grid_home.html
+++ b/content/grid_home.html
@@ -9,8 +9,8 @@
-
-
+
diff --git a/content/home.html b/content/home.html
index fa1ceb3..f441bd7 100644
--- a/content/home.html
+++ b/content/home.html
@@ -9,8 +9,8 @@
-
-
+
diff --git a/debian/changelog b/debian/changelog
new file mode 100644
index 0000000..cc070c1
--- /dev/null
+++ b/debian/changelog
@@ -0,0 +1,5 @@
+mobile-basic-flash (0.45+master) UNRELEASED; urgency=low
+
+ *
+
+ -- Alexander Sack Fri, 13 Jun 2008 13:42:02 +0200
diff --git a/po/LINGUAS b/po/LINGUAS
new file mode 100644
index 0000000..187dffb
--- /dev/null
+++ b/po/LINGUAS
@@ -0,0 +1 @@
+zh_CN
diff --git a/po/Makefile.in.in b/po/Makefile.in.in
index 22cadc6..6891e8f 100644
--- a/po/Makefile.in.in
+++ b/po/Makefile.in.in
@@ -1,46 +1,49 @@
# Makefile for program source directory in GNU NLS utilities package.
# Copyright (C) 1995, 1996, 1997 by Ulrich Drepper
+# Copyright (C) 2004-2008 Rodney Dawes
#
-# This file file be copied and used freely without restrictions. It can
-# be used in projects which are not available under the GNU Public License
+# This file may be copied and used freely without restrictions. It may
+# be used in projects which are not available under a GNU Public License,
# but which still want to provide support for the GNU gettext functionality.
-# Please note that the actual code is *not* freely available.
#
# - Modified by Owen Taylor to use GETTEXT_PACKAGE
# instead of PACKAGE and to look for po2tbl in ./ not in intl/
#
# - Modified by jacob berkman to install
# Makefile.in.in and po2tbl.sed.in for use with glib-gettextize
+#
+# - Modified by Rodney Dawes for use with intltool
+#
+# We have the following line for use by intltoolize:
+# INTLTOOL_MAKEFILE
GETTEXT_PACKAGE = @GETTEXT_PACKAGE@
PACKAGE = @PACKAGE@
VERSION = @VERSION@
SHELL = /bin/sh
-@SET_MAKE@
srcdir = @srcdir@
top_srcdir = @top_srcdir@
-top_builddir = ..
+top_builddir = @top_builddir@
VPATH = @srcdir@
prefix = @prefix@
exec_prefix = @exec_prefix@
datadir = @datadir@
+datarootdir = @datarootdir@
libdir = @libdir@
-localedir = $(libdir)/locale
-gnulocaledir = $(datadir)/locale
-gettextsrcdir = $(datadir)/glib-2.0/gettext/po
+DATADIRNAME = @DATADIRNAME@
+itlocaledir = $(prefix)/$(DATADIRNAME)/locale
subdir = po
install_sh = @install_sh@
-mkdir_p = @mkdir_p@
-mkinstalldirs = $(SHELL) $(top_srcdir)/mkinstalldirs
+# Automake >= 1.8 provides @mkdir_p@.
+# Until it can be supposed, use the safe fallback:
+mkdir_p = $(install_sh) -d
INSTALL = @INSTALL@
INSTALL_DATA = @INSTALL_DATA@
-CC = @CC@
-GENCAT = @GENCAT@
GMSGFMT = @GMSGFMT@
MSGFMT = @MSGFMT@
XGETTEXT = @XGETTEXT@
@@ -49,35 +52,30 @@ INTLTOOL_EXTRACT = @INTLTOOL_EXTRACT@
MSGMERGE = INTLTOOL_EXTRACT=$(INTLTOOL_EXTRACT) srcdir=$(srcdir) $(INTLTOOL_UPDATE) --gettext-package $(GETTEXT_PACKAGE) --dist
GENPOT = INTLTOOL_EXTRACT=$(INTLTOOL_EXTRACT) srcdir=$(srcdir) $(INTLTOOL_UPDATE) --gettext-package $(GETTEXT_PACKAGE) --pot
-DEFS = @DEFS@
-CFLAGS = @CFLAGS@
-CPPFLAGS = @CPPFLAGS@
+ALL_LINGUAS = @ALL_LINGUAS@
+
+PO_LINGUAS=$(shell if test -r $(srcdir)/LINGUAS; then grep -v "^\#" $(srcdir)/LINGUAS; fi)
-INCLUDES = -I.. -I$(top_srcdir)/intl
+USER_LINGUAS=$(shell if test -n "$(LINGUAS)"; then LLINGUAS="$(LINGUAS)"; ALINGUAS="$(ALL_LINGUAS)"; for lang in $$LLINGUAS; do if test -n "`grep ^$$lang$$ $(srcdir)/LINGUAS`" -o -n "`echo $$ALINGUAS|grep ' ?$$lang ?'`"; then printf "$$lang "; fi; done; fi)
-COMPILE = $(CC) -c $(DEFS) $(INCLUDES) $(CPPFLAGS) $(CFLAGS) $(XCFLAGS)
+USE_LINGUAS=$(shell if test -n "$(USER_LINGUAS)"; then LLINGUAS="$(USER_LINGUAS)"; else if test -n "$(PO_LINGUAS)"; then LLINGUAS="$(PO_LINGUAS)"; else LLINGUAS="$(ALL_LINGUAS)"; fi; fi; for lang in $$LLINGUAS; do printf "$$lang "; done)
-SOURCES =
-POFILES = @POFILES@
-GMOFILES = @GMOFILES@
-DISTFILES = ChangeLog Makefile.in.in POTFILES.in \
-$(POFILES) $(GMOFILES) $(SOURCES)
+POFILES=$(shell LINGUAS="$(USE_LINGUAS)"; for lang in $$LINGUAS; do printf "$$lang.po "; done)
+
+DISTFILES = ChangeLog Makefile.in.in POTFILES.in $(POFILES)
+EXTRA_DISTFILES = POTFILES.skip Makevars LINGUAS
POTFILES = \
+# This comment gets stripped out
-CATALOGS = @CATALOGS@
-CATOBJEXT = @CATOBJEXT@
-INSTOBJEXT = @INSTOBJEXT@
+CATALOGS=$(shell LINGUAS="$(USE_LINGUAS)"; for lang in $$LINGUAS; do printf "$$lang.gmo "; done)
.SUFFIXES:
-.SUFFIXES: .c .o .po .pox .gmo .mo .msg .cat
-
-.c.o:
- $(COMPILE) $<
+.SUFFIXES: .po .pox .gmo .mo .msg .cat
.po.pox:
$(MAKE) $(GETTEXT_PACKAGE).pot
- $(MSGMERGE) $< $(top_builddir)/po/$(GETTEXT_PACKAGE).pot -o $*pox
+ $(MSGMERGE) $< $(GETTEXT_PACKAGE).pot -o $*.pox
.po.mo:
$(MSGFMT) -o $@ $<
@@ -88,7 +86,7 @@ INSTOBJEXT = @INSTOBJEXT@
.po.cat:
sed -f ../intl/po2msg.sed < $< > $*.msg \
- && rm -f $@ && $(GENCAT) $@ $*.msg
+ && rm -f $@ && gencat $@ $*.msg
all: all-@USE_NLS@
@@ -99,115 +97,91 @@ all-no:
$(GETTEXT_PACKAGE).pot: $(POTFILES)
$(GENPOT)
-install: install-exec install-data
-install-exec:
+install: install-data
install-data: install-data-@USE_NLS@
install-data-no: all
install-data-yes: all
- if test -n "$(MKINSTALLDIRS)"; then \
- $(MKINSTALLDIRS) $(DESTDIR)$(datadir); \
- else \
- $(SHELL) $(top_srcdir)/mkinstalldirs $(DESTDIR)$(datadir); \
- fi
- @catalogs='$(CATALOGS)'; \
- for cat in $$catalogs; do \
- cat=`basename $$cat`; \
- case "$$cat" in \
- *.gmo) destdir=$(gnulocaledir);; \
- *) destdir=$(localedir);; \
- esac; \
- lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
- dir=$(DESTDIR)$$destdir/$$lang/LC_MESSAGES; \
- if test -n "$(MKINSTALLDIRS)"; then \
- $(MKINSTALLDIRS) $$dir; \
+ $(mkdir_p) $(DESTDIR)$(itlocaledir)
+ linguas="$(USE_LINGUAS)"; \
+ for lang in $$linguas; do \
+ dir=$(DESTDIR)$(itlocaledir)/$$lang/LC_MESSAGES; \
+ $(mkdir_p) $$dir; \
+ if test -r $$lang.gmo; then \
+ $(INSTALL_DATA) $$lang.gmo $$dir/$(GETTEXT_PACKAGE).mo; \
+ echo "installing $$lang.gmo as $$dir/$(GETTEXT_PACKAGE).mo"; \
else \
- $(SHELL) $(top_srcdir)/mkinstalldirs $$dir; \
+ $(INSTALL_DATA) $(srcdir)/$$lang.gmo $$dir/$(GETTEXT_PACKAGE).mo; \
+ echo "installing $(srcdir)/$$lang.gmo as" \
+ "$$dir/$(GETTEXT_PACKAGE).mo"; \
fi; \
- if test -r $$cat; then \
- $(INSTALL_DATA) $$cat $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT); \
- echo "installing $$cat as $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT)"; \
+ if test -r $$lang.gmo.m; then \
+ $(INSTALL_DATA) $$lang.gmo.m $$dir/$(GETTEXT_PACKAGE).mo.m; \
+ echo "installing $$lang.gmo.m as $$dir/$(GETTEXT_PACKAGE).mo.m"; \
else \
- $(INSTALL_DATA) $(srcdir)/$$cat $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT); \
- echo "installing $(srcdir)/$$cat as" \
- "$$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT)"; \
- fi; \
- if test -r $$cat.m; then \
- $(INSTALL_DATA) $$cat.m $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m; \
- echo "installing $$cat.m as $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m"; \
- else \
- if test -r $(srcdir)/$$cat.m ; then \
- $(INSTALL_DATA) $(srcdir)/$$cat.m \
- $$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m; \
- echo "installing $(srcdir)/$$cat as" \
- "$$dir/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m"; \
+ if test -r $(srcdir)/$$lang.gmo.m ; then \
+ $(INSTALL_DATA) $(srcdir)/$$lang.gmo.m \
+ $$dir/$(GETTEXT_PACKAGE).mo.m; \
+ echo "installing $(srcdir)/$$lang.gmo.m as" \
+ "$$dir/$(GETTEXT_PACKAGE).mo.m"; \
else \
true; \
fi; \
fi; \
done
- if test "$(PACKAGE)" = "glib"; then \
- if test -n "$(MKINSTALLDIRS)"; then \
- $(MKINSTALLDIRS) $(DESTDIR)$(gettextsrcdir); \
- else \
- $(SHELL) $(top_srcdir)/mkinstalldirs $(DESTDIR)$(gettextsrcdir); \
- fi; \
- $(INSTALL_DATA) $(srcdir)/Makefile.in.in \
- $(DESTDIR)$(gettextsrcdir)/Makefile.in.in; \
- else \
- : ; \
- fi
+
+# Empty stubs to satisfy archaic automake needs
+dvi info tags TAGS ID:
# Define this as empty until I found a useful application.
-installcheck:
+install-exec installcheck:
uninstall:
- catalogs='$(CATALOGS)'; \
- for cat in $$catalogs; do \
- cat=`basename $$cat`; \
- lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
- rm -f $(DESTDIR)$(localedir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE)$(INSTOBJEXT); \
- rm -f $(DESTDIR)$(localedir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m; \
- rm -f $(DESTDIR)$(gnulocaledir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE)$(INSTOBJEXT); \
- rm -f $(DESTDIR)$(gnulocaledir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE)$(INSTOBJEXT).m; \
+ linguas="$(USE_LINGUAS)"; \
+ for lang in $$linguas; do \
+ rm -f $(DESTDIR)$(itlocaledir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE).mo; \
+ rm -f $(DESTDIR)$(itlocaledir)/$$lang/LC_MESSAGES/$(GETTEXT_PACKAGE).mo.m; \
done
- if test "$(PACKAGE)" = "glib"; then \
- rm -f $(DESTDIR)$(gettextsrcdir)/Makefile.in.in; \
- fi
-check: all
-
-dvi info tags TAGS ID:
+check: all $(GETTEXT_PACKAGE).pot
+ rm -f missing notexist
+ srcdir=$(srcdir) $(INTLTOOL_UPDATE) -m
+ if [ -r missing -o -r notexist ]; then \
+ exit 1; \
+ fi
mostlyclean:
- rm -f core core.* *.pox $(GETTEXT_PACKAGE).pot *.old.po cat-id-tbl.tmp
- rm -fr *.o
+ rm -f *.pox $(GETTEXT_PACKAGE).pot *.old.po cat-id-tbl.tmp
rm -f .intltool-merge-cache
clean: mostlyclean
distclean: clean
- rm -f Makefile Makefile.in POTFILES *.mo *.msg *.cat *.cat.m
+ rm -f Makefile Makefile.in POTFILES stamp-it
+ rm -f *.mo *.msg *.cat *.cat.m *.gmo
maintainer-clean: distclean
@echo "This command is intended for maintainers to use;"
@echo "it deletes files that may require special tools to rebuild."
- rm -f $(GMOFILES)
+ rm -f Makefile.in.in
-distdir = ../$(GETTEXT_PACKAGE)-$(VERSION)/$(subdir)
-dist distdir: $(DISTFILES) $(GETTEXT_PACKAGE).pot
+distdir = ../$(PACKAGE)-$(VERSION)/$(subdir)
+dist distdir: $(DISTFILES)
dists="$(DISTFILES)"; \
+ extra_dists="$(EXTRA_DISTFILES)"; \
+ for file in $$extra_dists; do \
+ test -f $(srcdir)/$$file && dists="$$dists $(srcdir)/$$file"; \
+ done; \
for file in $$dists; do \
- ln $(srcdir)/$$file $(distdir) 2> /dev/null \
- || cp -p $(srcdir)/$$file $(distdir); \
+ test -f $$file || file="$(srcdir)/$$file"; \
+ ln $$file $(distdir) 2> /dev/null \
+ || cp -p $$file $(distdir); \
done
update-po: Makefile
$(MAKE) $(GETTEXT_PACKAGE).pot
tmpdir=`pwd`; \
- catalogs='$(CATALOGS)'; \
- for cat in $$catalogs; do \
- cat=`basename $$cat`; \
- lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
+ linguas="$(USE_LINGUAS)"; \
+ for lang in $$linguas; do \
echo "$$lang:"; \
result="`$(MSGMERGE) -o $$tmpdir/$$lang.new.po $$lang`"; \
if $$result; then \
@@ -223,32 +197,20 @@ update-po: Makefile
fi; \
fi; \
else \
- echo "msgmerge for $$cat failed!"; \
+ echo "msgmerge for $$lang.gmo failed!"; \
rm -f $$tmpdir/$$lang.new.po; \
fi; \
done
-# POTFILES is created from POTFILES.in by stripping comments, empty lines
-# and Intltool tags (enclosed in square brackets), and appending a full
-# relative path to them
-POTFILES: POTFILES.in
- ( if test 'x$(srcdir)' != 'x.'; then \
- posrcprefix='$(top_srcdir)/'; \
- else \
- posrcprefix="../"; \
- fi; \
- rm -f $@-t $@ \
- && (sed -e '/^#/d' \
- -e "s/^\[.*\] +//" \
- -e '/^[ ]*$$/d' \
- -e "s@.*@ $$posrcprefix& \\\\@" < $(srcdir)/$@.in \
- | sed -e '$$s/\\$$//') > $@-t \
- && chmod a-w $@-t \
- && mv $@-t $@ )
-
-Makefile: Makefile.in.in ../config.status POTFILES
- cd .. \
- && CONFIG_FILES=$(subdir)/$@.in CONFIG_HEADERS= \
+Makefile POTFILES: stamp-it
+ @if test ! -f $@; then \
+ rm -f stamp-it; \
+ $(MAKE) stamp-it; \
+ fi
+
+stamp-it: Makefile.in.in $(top_builddir)/config.status POTFILES.in
+ cd $(top_builddir) \
+ && CONFIG_FILES=$(subdir)/Makefile.in CONFIG_HEADERS= CONFIG_LINKS= \
$(SHELL) ./config.status
# Tell versions [3.59,3.63) of GNU make not to export all variables.
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 8e01703..3f7e38a 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -1,2 +1 @@
-src/dummy-panel-plugin.c
-src/dummy-home-plugin.c
+src/mobile-basic-home-plugin.c
diff --git a/po/zh_CN.po b/po/zh_CN.po
new file mode 100644
index 0000000..0a0ba14
--- /dev/null
+++ b/po/zh_CN.po
@@ -0,0 +1,18 @@
+# Simplified Chinese translation script for mobile-basic-flash-plugins.
+# Copyright (C) 2008 Intel Corporation
+# This file is distributed under the same license as the marquee-plugins package.
+# Li, Horace , 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: \n"
+"Report-Msgid-Bugs-To: \n"
+"PO-Revision-Date: 2008-05-12 10:38 +0800\n"
+"Last-Translator: Li, Horace \n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+
+#: ../src/mobile-basic-home-plugin.c:404
+msgid "Starting %s..."
+msgstr "%s 正在启动..."
diff --git a/src/Makefile.am b/src/Makefile.am
index f51af20..e270b53 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -7,7 +7,7 @@ INCLUDES = $(GTK_CFLAGS) \
$(LIBWNCK_CFLAGS) \
$(MOZEMBED_CFLAGS)
-LDFLAGS = -module -avoid-version
+AM_LDFLAGS = -module -avoid-version
mobilebasichome_LTLIBRARIES = libmobilebasichome.la
diff --git a/src/mobile-basic-home-plugin.h b/src/mobile-basic-home-plugin.h
index b338fed..1ac2c7e 100644
--- a/src/mobile-basic-home-plugin.h
+++ b/src/mobile-basic-home-plugin.h
@@ -36,6 +36,11 @@
#include
#define WNCK_I_KNOW_THIS_IS_UNSTABLE
#include
+#include
+
+#include "config.h"
+
+#define _(String) dgettext (GETTEXT_PACKAGE, String)
G_BEGIN_DECLS
diff --git a/src/mobile-basic-home-plugin.cpp b/src/mobile-basic-home-plugin.cpp
index 48fca21..261c4fc 100644
--- a/src/mobile-basic-home-plugin.cpp
+++ b/src/mobile-basic-home-plugin.cpp
@@ -147,13 +147,10 @@ extern "C" {
static GdkFilterReturn mobile_basic_home_x_event_handler (GdkXEvent *xevent,
GdkEvent *event, gpointer data);
static void home_screen_changed (HildonDesktopHomeItem *item);
-
void init_window_helper (plugin_context_t *context);
void hide_banner(void);
- static void home_screen_changed (HildonDesktopHomeItem *item);
static void start_plugin(plugin_context_t *, gchar*);
-
gint compare_items(gconstpointer a, gconstpointer b);
static gboolean is_app_in_ignore_list (GSList *ignore_list, gchar *app);
@@ -297,6 +294,12 @@ void hide_banner (void)
}
}
+static gboolean force_banner_hide (gpointer data)
+{
+ hide_banner ();
+ return FALSE;
+}
+
static void show_banner (const gchar *msg)
{
// make sure we are not already showing a launchBanner
@@ -401,7 +404,7 @@ static void launch_app(plugin_context_t *c, application_entry_t *item)
//Show banner during startup.
//Banner is hidden in callback: window_stack_change_cb
- gchar* msg = g_strdup_printf("Starting %s...", item->name);
+ gchar* msg = g_strdup_printf(_("Starting %s..."), item->name);
show_banner(msg);
if (item->service) {
@@ -493,8 +496,8 @@ static void launch_app(plugin_context_t *c, application_entry_t *item)
}
}
- // Hide banner after 15s if not already hidden
- //g_timeout_add (15*1000, force_banner_hide, NULL);
+ //Hide banner after 10s if not already hidden
+ g_timeout_add (10*1000, force_banner_hide, NULL);
}
static void start_app_from_index(plugin_context_t *c, int index)
@@ -1020,6 +1023,9 @@ static void mobile_basic_home_plugin_init (MobileBasicHomePlugin *home_plugin)
g_print("mobile_basic_home_plugin_init\n");
+ bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+ bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
#ifdef XPCOM_GLUE
static const GREVersionRange greVersion = {
"1.9a", PR_TRUE,